@@ -96,6 +96,7 @@ OC.L10N.register(
     "A group call has started in {call}" : "Ryhmäpuhelu on alkanut puhelussa {call}",
     "Open settings" : "Avaa asetukset",
     "Conversations" : "Keskustelut",
+    "Messages" : "Viestit",
     "Austria" : "Itävalta",
     "Belgium" : "Belgia",
     "Bulgaria" : "Bulgaria",
@@ -221,6 +222,7 @@ OC.L10N.register(
     "Enable video" : "Käytä videota",
     "Screensharing options" : "Näytönjakamisen valinnat",
     "Enable screensharing" : "Ota käyttöön näytönjakaminen",
+    "Back" : "Takaisin",
     "Screen sharing is not supported by your browser." : "Selaimesi ei tue näytönjakoa.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
     "Screensharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
@@ -246,11 +248,9 @@ OC.L10N.register(
     "No search results" : "Ei hakutuloksia",
     "Groups" : "Ryhmät",
     "Circles" : "Piirit",
+    "Settings" : "Asetukset",
     "Groups and circles" : "Ryhmät ja piirit",
     "Other sources" : "Muut lähteet",
-    "Select default location for attachments" : "Valitse liitteiden oletussijainti",
-    "Invalid path selected" : "Valittu virheellinen polku",
-    "Error while setting attachment folder" : "Virhe asettaessa liitekansiota",
     "Creating your conversation" : "Luodaan keskustelua",
     "Copy conversation link" : "Kopioi keskustelulinkki",
     "Error while creating the conversation" : "Virhe keskustelua luotaessa",
@@ -258,7 +258,6 @@ OC.L10N.register(
     "Create a new group conversation" : "Luo uusi ryhmäkeskustelu",
     "Password protect" : "Suojaa salasanalla",
     "Add participants" : "Lisää osallistujat",
-    "Back" : "Takaisin",
     "Create conversation" : "Luo keskustelu",
     "Close" : "Sulje",
     "Choose a password" : "Valitse salasana",
@@ -268,13 +267,23 @@ OC.L10N.register(
     "Allow guests to join via link " : "Salli vieraiden liittyminen linkin kautta",
     "You are currently waiting in the lobby" : "Odotat parhaillaan aulassa",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Odotat parhaillaan aulassa. Tapaaminen on ajoitettu alkavaksi {startTime}",
+    "Camera" : "Kamera",
     "Reply" : "Vastaa",
+    "Remove" : "Poista",
     "Today" : "Tänään",
     "Yesterday" : "Eilen",
     "Write message, @ to mention someone …" : "Kirjoita viesti, käytä @-merkkiä mainitaksesi käyttäjän…",
     "Upload new files" : "Lähetä uusia tiedostoja",
     "Send message" : "Lähetä viesti",
     "File to share" : "Jaettava tiedosto",
+    "Invalid path selected" : "Valittu virheellinen polku",
+    "Enabled" : "Käytössä",
+    "Save" : "Tallenna",
+    "Password" : "Salasana",
+    "API token" : "API-poletti",
+    "Login" : "Kirjaudu",
+    "Nickname" : "Nimimerkki",
+    "Client ID" : "Asiakkaan tunniste",
     "moderator" : "moderaattori",
     "guest" : "vieras",
     "Demote from moderator" : "Alenna moderaattorista",
@@ -291,10 +300,11 @@ OC.L10N.register(
     "Add participants to the conversation" : "Lisää osallistujia keskusteluun",
     "Participants" : "Osallistujat",
     "Chat" : "Keskustelu",
-    "Projects" : "Projektit",
-    "Settings" : "Asetukset",
     "Display name: " : "Näyttönimi:",
     "Edit" : "Muokkaa",
+    "Keyboard shortcuts" : "Pikanäppäimet",
+    "Search" : "Etsi",
+    "Error while setting attachment folder" : "Virhe asettaessa liitekansiota",
     "Start call" : "Aloita puhelu",
     "Go to file" : "Siirry tiedostoon",
     "Rename conversation" : "Nimeä keskustelu uudelleen",
@@ -306,17 +316,18 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Poistu koko näytön tilasta (f)",
     "Fullscreen (f)" : "Koko näytön tila (f)",
     "Grid view" : "Ruudukkonäkymä",
+    "Say hi to your friends and colleagues!" : "Sano hei ystävillesi ja työkavereillesi!",
+    "Start a conversation" : "Aloita keskustelu",
     "Message without mention" : "Viesti ilman mainintaa",
     "Mention room" : "Mainitse huone",
     "The conversation does not exist" : "Tätä keskustelua ei ole olemassa",
     "Join a conversation or start a new one!" : "Liity keskusteluun tai aloita uusi keskustelu!",
-    "Select a conversation to add to the project" : "Valitse projektiin lisättävä keskustelu",
+    "Link to a conversation" : "Linkki keskusteluun",
     "Select conversation" : "Valitse keskustelu",
     "Join a conversation or start a new one" : "Liity keskusteluun tai aloita uusi",
-    "Say hi to your friends and colleagues!" : "Sano hei ystävillesi ja työkavereillesi!",
-    "Link to a conversation" : "Linkki keskusteluun",
     "Error while sharing file" : "Virhe tiedostoa jakaessa",
     "Error while uploading file" : "Virhe tiedostoa lähettäessä",
+    "Default" : "Oletus",
     "You seem to be talking while muted, please unmute yourself for others to hear you" : "Vaikuttaa siltä, että puhut vaikka sinut on mykistetty. Poista mykistys, jotta muut kuulevat sinut",
     "Access to microphone & camera is only possible with HTTPS" : "Kameran ja mikrofonin käyttäminen on mahdollista vain käytettäessä HTTPS-protokollaa",
     "Please move your setup to HTTPS" : "Siirrä asetuksesi HTTPS:n taakse",
@@ -326,7 +337,6 @@ OC.L10N.register(
     "Error while accessing microphone & camera" : "Virhe yhdistettäessä mikrofoniin ja kameraan",
     "This conversation is password-protected" : "Tämä keskustelu on salasanasuojattu",
     "The password is wrong. Try again." : "Salasana on väärin. Yritä uudelleen.",
-    "Password" : "Salasana",
     "TURN server" : "TURN-palvelin",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-palvelinta käytetään liikenteen välittämisessä palomuurin takana oleville osallistujille.",
     "%s Talk on your mobile devices" : "%s Keskustele mobiililaitteillasi",
@@ -336,6 +346,7 @@ OC.L10N.register(
     "Enter name for a new conversation" : "Anna nimi uudelle keskustelulle",
     "{name} (public)" : "{name} (julkinen)",
     "New conversation …" : "Uusi keskustelu…",
+    "Projects" : "Projektit",
     "Copy" : "Kopioi",
     "Copied!" : "Kopioitu!",
     "Not supported!" : "Ei tuettu!",
@@ -387,6 +398,7 @@ OC.L10N.register(
     "Guest's screen" : "Vieraan näyttö",
     "Limit app usage to groups." : "Rajoita sovelluksen käyttö ryhmiin.",
     "Who can start a call?" : "Kuka voi aloittaa puhelun?",
+    "Select a conversation to add to the project" : "Valitse projektiin lisättävä keskustelu",
     "Join conversations at any time, any where, on any device." : "Liity keskusteluun milloin tahansa, mistä tahansa, miltä laitteelta tahansa.",
     "Contacts" : "Yhteystiedot",
     "Contacts, groups and circles" : "Yhteystiedot, ryhmät ja piirit",
@@ -399,6 +411,7 @@ OC.L10N.register(
     "Add contacts" : "Lisää yhteystietoja",
     "Add contacts, groups or circles" : "Lisää yhteystietoja, ryhmiä tai piirejä",
     "Add contacts or groups" : "Lisää yhteystietoja tai ryhmiä",
-    "Add contacts or circles" : "Lisää yhteystietoja tai piirejä"
+    "Add contacts or circles" : "Lisää yhteystietoja tai piirejä",
+    "Select default location for attachments" : "Valitse liitteiden oletussijainti"
 },
 "nplurals=2; plural=(n != 1);");
