@@ -20,33 +20,42 @@ OC.L10N.register(
     "Saved" : "Disimpan",
     "Copy link" : "Salin tautan",
     "Dismiss" : "Batal",
+    "Back" : "Kembali",
     "Drop your files to upload" : "Lepas berkas Anda untuk mengunggah",
     "Favorite" : "Favorit",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Tambah ke favorit",
     "Loading" : "Memuat",
     "Groups" : "Grup",
-    "Invalid path selected" : "Jalur terpilih invalid",
+    "Settings" : "Setelan",
     "Password protect" : "Lindungi dengan kata sandi",
-    "Back" : "Kembali",
     "Close" : "Tutup",
     "Reply" : "Balas",
+    "Remove" : "Buang",
     "Today" : "Hari ini",
     "Yesterday" : "Kemarin",
+    "Invalid path selected" : "Jalur terpilih invalid",
+    "Enabled" : "Diaktifkan",
+    "Save" : "Simpan",
+    "Password" : "Kata kunci",
+    "Login" : "Log masuk",
+    "Nickname" : "Nama panggilan",
+    "Client ID" : "ID Klien",
     "guest" : "pengunjung",
     "No results" : "Tidak ada hasil",
     "Add users or groups" : "Add users or groups",
-    "Projects" : "Proyek",
-    "Settings" : "Setelan",
     "Edit" : "Sunting",
+    "Keyboard shortcuts" : "Pintasan keyboard",
+    "Search" : "Cari",
     "Share link" : "Bagikan tautan",
     "Password protection" : "Password protection",
     "Enter a password" : "Masukkan kata sandi",
     "Grid view" : "Tampilan kotak",
+    "Default" : "Bawaan",
     "The password is wrong. Try again." : "Kata sandi salah. Coba lagi",
-    "Password" : "Kata kunci",
     "Android app" : "Aplikasi Android",
     "iOS app" : "Aplikasi iOS",
+    "Projects" : "Proyek",
     "Copy" : "Salin",
     "Copied!" : "Tersalin!",
     "Not supported!" : "Tidak didukung!",
