@@ -95,6 +95,7 @@ OC.L10N.register(
     "A group call has started in {call}" : "Hópsímtal er byrjað í {call}",
     "Open settings" : "Opna stillingar",
     "Conversations" : "Samtöl",
+    "Messages" : "Skilaboð",
     "Andorra" : "Andorra",
     "United Arab Emirates" : "Sameinuðu arabísku furstadæmin",
     "Afghanistan" : "Afganistan",
@@ -377,10 +378,8 @@ OC.L10N.register(
     "Blocked" : "Útilokaður",
     "Active" : "Virkt",
     "Expired" : "Útrunnið",
-    "Signaling server URL" : "Slóð á merkjasendingaþjón",
     "Validate SSL certificate" : "Sannreyna SSL-skilríki",
     "Delete this server" : "Eyða þessum þjóni",
-    "Signaling servers" : "Merkjasendingaþjónar",
     "Saved" : "Vistað",
     "Add a new server" : "Bæta við nýjum þjóni",
     "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Mögulegt er að nota utanaðkomandi merkjasendingaþjón fyrir mjög stórar uppsetningar. Skildu þetta eftir autt til að nota innbyggða merkjasendingaþjóninn.",
@@ -418,6 +417,7 @@ OC.L10N.register(
     "Enable video" : "Virkja myndskeið",
     "Screensharing options" : "Valkostir skjádeilingar",
     "Enable screensharing" : "Virkja skjádeilingu",
+    "Back" : "Til baka",
     "Screensharing requires the page to be loaded through HTTPS." : "Deiling á skjá krefst þess að síðunni sé hlaðið inn með HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Skjádeiling virkar aðeins með Firefox útgáfu 52 eða nýrri.",
     "Screensharing extension is required to share your screen." : "Það þarf skjádeili-viðaukann til að hægt sé að deila skjánum.",
@@ -434,17 +434,26 @@ OC.L10N.register(
     "Loading" : "Hleð inn",
     "Groups" : "Hópar",
     "Circles" : "Hringir",
-    "Invalid path selected" : "Ógild slóð valin",
+    "Settings" : "Stillingar",
     "Password protect" : "Verja með lykilorði",
-    "Back" : "Til baka",
     "Close" : "Loka",
     "Conversation name" : "Heiti samtals",
+    "Camera" : "Myndavél",
     "Reply" : "Svara",
+    "Remove" : "Fjarlægja",
     "Today" : "Í dag",
     "Yesterday" : "Í gær",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Send message" : "Senda skilaboð",
     "File to share" : "Skrá til að deila",
+    "Invalid path selected" : "Ógild slóð valin",
+    "Enabled" : "Virkt",
+    "Save" : "Vista",
+    "Password" : "Lykilorð",
+    "API token" : "API-teikn",
+    "Login" : "Innskráning",
+    "Nickname" : "Stuttnefni",
+    "Client ID" : "Biðlaraauðkenni",
     "moderator" : "umsjónarmaður",
     "guest" : "gestanotandi",
     "Demote from moderator" : "Láta hætta sem umsjónarmann",
@@ -455,9 +464,9 @@ OC.L10N.register(
     "Add users or groups" : "Bæta við notendum eða hópum",
     "Participants" : "Þátttakendur",
     "Chat" : "Spjall",
-    "Projects" : "Verkefni",
-    "Settings" : "Stillingar",
     "Edit" : "Breyta",
+    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
+    "Search" : "Search",
     "Start call" : "Hefja samtal",
     "Go to file" : "Fara í skrá",
     "Rename conversation" : "Endurnefna samtal",
@@ -468,11 +477,12 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Hætta í skjáfylli (f)",
     "Fullscreen (f)" : "Fylla skjáinn (f)",
     "Grid view" : "Reitasýn",
-    "Select a conversation to add to the project" : "Veldu samtal sem á að bæta við verkefnið",
+    "Say hi to your friends and colleagues!" : "Segðu hæ við vini þína og samstarfsmenn!",
+    "Start a conversation" : "Hefja samtal",
+    "Link to a conversation" : "Tengill á samtal",
     "Select conversation" : "Veldu samtal",
     "Join a conversation or start a new one" : "Taktu þátt í samtali eða byrjaðu nýtt samtal",
-    "Say hi to your friends and colleagues!" : "Segðu hæ við vini þína og samstarfsmenn!",
-    "Link to a conversation" : "Tengill á samtal",
+    "Default" : "Sjálfgefið",
     "Access to microphone & camera is only possible with HTTPS" : "Aðgangur að hljóðnema og myndavél er einungis mögulegur í gegnum HTTPS",
     "Please move your setup to HTTPS" : "Endilega færðu uppsetninguna þína yfir í HTTPS",
     "Access to microphone & camera was denied" : "Aðgangur að hljóðnema og myndavél var ekki heimilaður",
@@ -481,10 +491,10 @@ OC.L10N.register(
     "Error while accessing microphone & camera" : "Villa kom upp þegar reynt var að opna hljóðnema og myndavél",
     "This conversation is password-protected" : "Þetta samtal er er varið með lykilorði",
     "The password is wrong. Try again." : "Lykilorðið er rangt. Reyndu aftur.",
-    "Password" : "Lykilorð",
     "Specify commands the users can use in chats" : "Tilgreindu hvaða skipanir notendur geta notað í spjalli",
     "TURN server" : "TURN-þjónn",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-miðlari er notaður sem milliþjónn umferðar þátttakenda á bak við eldvegg.",
+    "Signaling servers" : "Merkjasendingaþjónar",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Mögulegt er að nota utanaðkomandi merkjasendingaþjón fyrir mjög stórar uppsetningar. Skildu þetta eftir autt til að nota innbyggða merkjasendingaþjóninn.",
     "%s Talk on your mobile devices" : "%s Talaðu á snjalltækjunum þínum",
     "Android app" : "Android-forrit",
@@ -492,6 +502,7 @@ OC.L10N.register(
     "Enter name for a new conversation" : "Settu inn nafn fyrir nýtt samtal",
     "{name} (public)" : "{name} (opinbert)",
     "New conversation …" : "Nýtt samtal…",
+    "Projects" : "Verkefni",
     "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Samtöl með fleiri en 4 þátttakendum og án merkjasendingaþjóns geta orðið fyrir truflunum í tengingum ásamt því að valda miklu álagi á tengdum tækjum.",
     "Copy" : "Afrita",
     "Copied!" : "Afritað!",
@@ -541,9 +552,11 @@ OC.L10N.register(
     "Guest's screen" : "Skjár gests",
     "Limit app usage to groups." : "Takmarka notkun forrits við tiltekna hópa.",
     "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our <a {attributes}>documentation ↗</a>." : "Skipanir er nýr eiginleiki í Nextcloud Talk. Þær gera þér kleift að keyra skriftur á Nextcloud-þjóninum þínum. Þú getur skilgreint þær með skipanalínuviðmóti okkar. Þæmi um reiknivélarskriftu má finna í <a {attributes}>hjálparskjölunum ↗</a>.",
+    "Select a conversation to add to the project" : "Veldu samtal sem á að bæta við verkefnið",
     "A TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-miðlari er notaður sem milliþjónn umferðar þátttakenda á bak við eldvegg.",
     "Join conversations at any time, any where, on any device." : "Taktu þátt í samtölum hvenær sem er, hvar sem er, á hvaða tæki sem er.",
     "Contacts" : "Tengiliðir",
-    "Search conversations or contacts" : "Leita í samtölum eða tengiliðum"
+    "Search conversations or contacts" : "Leita í samtölum eða tengiliðum",
+    "Signaling server URL" : "Slóð á merkjasendingaþjón"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
