@@ -29,6 +29,7 @@ OC.L10N.register(
     "- You can now directly reply to messages giving the other users more context what your message is about" : "- Dabar, galite tiesiogiai atsakyti į žinutes, suteikdami kitiems naudotojams daugiau konteksto apie ką yra jūsų žinutė",
     "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Dabar, pokalbių ir dalyvių paieška taip pat filtruos ir jūsų esamus pokalbius, todėl bus žymiai lengviau rasti ankstesnius pokalbius",
     "- You can now add custom user groups to conversations when the circles app is installed" : "- Nuo šiol, kai turite įdiegtą ratų programėlę, galite pridėti į pokalbius tinkintas naudotojų grupes",
+    "New in Talk 9" : "Nauja Pokalbiuose 9",
     "There are currently no commands available." : "Šiuo metu nėra prieinamų komandų.",
     "The command does not exist" : "Komandos nėra",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "Vykdant komandą, įvyko klaida. Paprašykite administratoriaus, kad patikrintų žurnalus.",
@@ -133,6 +134,12 @@ OC.L10N.register(
     "Someone tried to request the password to access {file}" : "Kažkas bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
     "Open settings" : "Atverti nustatymus",
     "Conversations" : "Pokalbiai",
+    "Messages" : "Žinutės",
+    "{user}" : "{user}",
+    "Something unexpected happened." : "Nutiko kažkas netikėto.",
+    "The URL is invalid." : "URL yra neteisingas.",
+    "The email address is invalid." : "El. pašto adresas yra neteisingas.",
+    "Something unexpected happened. Please try again later." : "Nutiko kažkas netikėto. Vėliau bandykite dar kartą.",
     "Andorra" : "Andora",
     "United Arab Emirates" : "Jungtiniai Arabų Emyratai",
     "Afghanistan" : "Afganistanas",
@@ -314,6 +321,7 @@ OC.L10N.register(
     "Path is already shared with this room" : "Kelias jau yra bendrinamas su šiuo kambariu",
     "Chat, video & audio-conferencing using WebRTC" : "Pokalbiai, vaizdo ir garso konferencijos naudojant WebRTC",
     "Leave call" : "Išeiti iš skambučio",
+    "Stay in call" : "Pasilikti skambutyje",
     "Discuss this file" : "Aptarkite šį failą",
     "Share this file with others to discuss it" : "Bendrinti šį failą su kitais, norint jį aptarti",
     "Share this file" : "Bendrinti šį failą",
@@ -357,12 +365,12 @@ OC.L10N.register(
     "Expired" : "Nebegalioja",
     "The account could not be deleted. Please try again later." : "Nepavyko ištrinti paskyros. Vėliau bandykite dar kartą.",
     "_%n user_::_%n users_" : ["%n naudotojas","%n naudotojai","%n naudotojų","%n naudotojas"],
-    "Signaling server URL" : "Signalinio serverio URL",
+    "Downloading …" : "Atsisiunčiama…",
+    "Installed version: {version}" : "Įdiegta versija: {version}",
     "Delete this server" : "Ištrinti šį serverį",
     "Status: Checking connection" : "Būsena: Tikrinamas ryšys",
     "Error: Can not connect to server" : "Klaida: Nepavyksta prisijungti prie serverio",
     "Error: Unknown error occurred" : "Klaida: Įvyko nežinoma klaida",
-    "Signaling servers" : "Signaliniai serveriai",
     "Saved" : "Įrašyta",
     "Add a new server" : "Pridėti naują serverį",
     "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Didesniems diegimams pasirinktinai turėtų būti naudojamas signalinis serveris. Palikite tuščią norėdami naudoti vidinį signalinį serverį.",
@@ -404,6 +412,7 @@ OC.L10N.register(
     "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą. Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
     "Screensharing options" : "Ekrano bendrinimo parinktys",
     "Enable screensharing" : "Įjungti ekrano bendrinimą",
+    "Back" : "Atgal",
     "Screen sharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
@@ -430,12 +439,12 @@ OC.L10N.register(
     "No search results" : "Nėra paieškos rezultatų",
     "Groups" : "Grupės",
     "Circles" : "Ratai",
-    "Default location for attachments" : "Numatytoji priedų vieta",
+    "Settings" : "Nustatymai",
+    "Users, groups and circles" : "Naudotojai, grupės ir ratai",
+    "Users and groups" : "Naudotojai ir grupės",
+    "Users and circles" : "Naudotojai ir ratai",
     "Groups and circles" : "Grupės ir ratai",
     "Other sources" : "Kiti šaltiniai",
-    "Select default location for attachments" : "Pasirinkti numatytąją vietą priedams",
-    "Invalid path selected" : "Pasirinktas neteisingas kelias",
-    "Error while setting attachment folder" : "Klaida nustatant priedų aplanką",
     "Creating your conversation" : "Kuriamas jūsų pokalbis",
     "All set" : "Viskas paruošta",
     "Copy conversation link" : "Kopijuoti pokalbio nuorodą",
@@ -444,16 +453,25 @@ OC.L10N.register(
     "Create a new group conversation" : "Sukurti naują grupės pokalbį",
     "Password protect" : "Apsaugoti slaptažodžiu",
     "Add participants" : "Pridėti dalyvius",
-    "Back" : "Atgal",
     "Create conversation" : "Sukurti pokalbį",
     "Close" : "Užverti",
     "Search participants" : "Ieškoti dalyvių",
     "An error occurred while performing the search" : "Atliekant paiešką, įvyko klaida",
     "Conversation name" : "Pokalbio pavadinimas",
     "Allow guests to join via link " : "Leisti svečiams prisijungti per nuorodą",
+    "Search conversations or users" : "Ieškoti pokalbių ar naudotojų",
     "You are currently waiting in the lobby" : "Šiuo metu laukiate laukimo salėje",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Šiuo metu laukiate laukimo salėje. Šio susitikimo pradžia yra suplanuota {startTime}",
+    "Calls are not supported in your browser" : "Jūsų naršyklėje skambučiai yra nepalaikomi",
+    "Access to microphone is only possible with HTTPS" : "Prieiga prie mikrofono yra įmanoma tik naudojant HTTPS",
+    "Error while accessing microphone" : "Klaida gaunant prieigą prie mikrofono",
+    "Access to camera is only possible with HTTPS" : "Prieiga prie kameros yra įmanoma tik naudojant HTTPS",
+    "Microphone" : "Mikrofonas",
+    "Camera" : "Kamera",
+    "No microphone available" : "Nėra prieinamo mikrofono",
+    "No camera available" : "Nėra prieinamos kameros",
     "Reply" : "Atsakyti",
+    "Remove" : "Šalinti",
     "[Unknown username]" : "[Nežinomas naudotojo vardas]",
     "Today" : "Šiandien",
     "Yesterday" : "Vakar",
@@ -462,6 +480,28 @@ OC.L10N.register(
     "Share from Files" : "Bendrinti iš Failų",
     "Send message" : "Siųsti žinutę",
     "File to share" : "Failas, kurį bendrinti",
+    "Invalid path selected" : "Pasirinktas neteisingas kelias",
+    "Enabled" : "Įjungta",
+    "Save" : "Įrašyti",
+    "Nextcloud URL" : "Nextcloud URL",
+    "Nextcloud user" : "Nextcloud naudotojas",
+    "User password" : "Naudotojo slaptažodis",
+    "Matrix server URL" : "Matrix serverio URL",
+    "Matrix channel" : "Matrix kanalas",
+    "Channel name" : "Kanalo pavadinimas",
+    "Rocket.Chat server URL" : "Rocket.Chat serverio URL",
+    "User name or e-mail address" : "Naudotojo vardas ar el. pašto adresas",
+    "Password" : "Slaptažodis",
+    "Rocket.Chat channel" : "Rocket.Chat kanalas",
+    "API token" : "API prieigos raktas",
+    "Slack channel" : "Slack kanalas",
+    "Server ID or name" : "Serverio ID ar pavadinimas",
+    "Channel ID or name" : "Kanalo ID ar pavadinimas",
+    "Login" : "Prisijungti",
+    "Nickname" : "Slapyvardis",
+    "IRC channel" : "IRC kanalas",
+    "Client ID" : "Kliento ID",
+    "MUC server URL" : "MUC serverio URL",
     "moderator" : "moderatorius",
     "guest" : "svečias",
     "Participant settings" : "Dalyvio nustatymai",
@@ -480,10 +520,12 @@ OC.L10N.register(
     "Participants" : "Dalyviai",
     "An error occurred while fetching the participants" : "Gaunant dalyvius, įvyko klaida",
     "Chat" : "Pokalbis",
-    "Projects" : "Projektai",
-    "Settings" : "Nustatymai",
     "Display name: " : "Rodomas vardas: ",
     "Edit" : "Taisyti",
+    "Attachments folder" : "Priedų aplankas",
+    "Keyboard shortcuts" : "Klavišų kombinacijos",
+    "Search" : "Ieškoti",
+    "Error while setting attachment folder" : "Klaida nustatant priedų aplanką",
     "Start call" : "Pradėti skambutį",
     "Toggle fullscreen" : "Perjungti visą ekraną",
     "Go to file" : "Pereiti į failą",
@@ -496,20 +538,25 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Išeiti iš viso ekrano (f)",
     "Fullscreen (f)" : "Visas ekranas (f)",
     "Grid view" : "Tinklelio rodinys",
+    "Say hi to your friends and colleagues!" : "Pasisveikinkite su savo draugais ir kolegomis!",
+    "Start a conversation" : "Pradėti pokalbį",
     "Message without mention" : "Rašyti be paminėjimo",
     "Mention myself" : "Paminėti save",
     "Mention room" : "Paminėti kambarį",
     "The conversation does not exist" : "Pokalbio nėra",
     "Join a conversation or start a new one!" : "Prisijunkite prie pokalbio arba pradėkite naują!",
     "Join a conversation or start a new one" : "Prisijunkite prie pokalbio arba pradėkite naują",
-    "Say hi to your friends and colleagues!" : "Pasisveikinkite su savo draugais ir kolegomis!",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Nextcloud Pokalbiai pilnai nepalaiko jūsų naudojamos naršyklės. Naudokite naujausią Mozilla Firefox, Microsoft Edge, Google Chrome ar Apple Safari versiją.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Pokalbiai buvo atnaujinti, įkelkite puslapį iš naujo",
+    "Do not disturb" : "Netrukdyti",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud yra techninės priežiūros veiksenoje, įkelkite puslapį iš naujo",
     "Error while sharing file" : "Klaida bendrinant failą",
     "Sending signaling message has failed." : "Nepavyko išsiųsti signalinės žinutės.",
     "Establishing signaling connection is taking longer than expected …" : "Signalinio ryšio užmezgimas trunka ilgiau nei tikėtasi…",
     "Failed to establish signaling connection. Retrying …" : "Nepavyko užmegzti signalinio ryšio. Bandoma iš naujo…",
+    "Default" : "Numatytoji",
+    "Microphone {number}" : "Mikrofonas {number}",
+    "Camera {number}" : "Kamera {number}",
     "You seem to be talking while muted, please unmute yourself for others to hear you" : "Atrodo, kad kalbate su išjungtu mikrofonu, įjunkite savo garsą, jei norite, kad kiti jus girdėtų",
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tai užtrunka ilgiau, nei tikėtasi. Ar medijos leidimai jau yra suteikti (arba atmesti)? Jeigu taip, tuomet paleiskite savo naršyklę iš naujo, nes garsas ir vaizdas patiria nesėkmę",
     "Access to microphone & camera is only possible with HTTPS" : "Prieiga prie mikrofono ir kameros yra įmanoma tik naudojant HTTPS",
@@ -520,8 +567,8 @@ OC.L10N.register(
     "Error while accessing microphone & camera" : "Klaida, gaunant prieigą prie mikrofono ir kameros",
     "This conversation is password-protected" : "Šis pokalbis yra apsaugotas slaptažodžiu",
     "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
-    "Password" : "Slaptažodis",
     "TURN server" : "TURN serveris",
+    "Signaling servers" : "Signaliniai serveriai",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Didesniems diegimams pasirinktinai gali būti naudojamas signalinis serveris. Palikite tuščią norėdami naudoti vidinį signalinį serverį.",
     "%s Talk on your mobile devices" : "%s Pokalbiai jūsų mobiliuosiuose įrenginiuose",
     "Join conversations at any time, anywhere, on any device." : "Prisijunkite prie pokalbių bet kur, bet kada, bet kokiame įrenginyje.",
@@ -530,6 +577,7 @@ OC.L10N.register(
     "Enter name for a new conversation" : "Įveskite naujo pokalbio pavadinimą",
     "{name} (public)" : "{name} (viešas)",
     "New conversation …" : "Naujas pokalbis …",
+    "Projects" : "Projektai",
     "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Skambučiuose su daugiau kaip 4 dalyviais be išorinio signalinio serverio gali būti patiriamos ryšio problemos ir sukeliama didelė apkrova dalyvaujantiems įrenginiams.",
     "Copy" : "Kopijuoti",
     "Copied!" : "Nukopijuota!",
@@ -600,6 +648,9 @@ OC.L10N.register(
     "Add contacts" : "Pridėti adresatus",
     "Add contacts, groups or circles" : "Pridėti adresatus, grupes ar ratus",
     "Add contacts or groups" : "Pridėti adresatus ar grupes",
-    "Add contacts or circles" : "Pridėti adresatus ar ratus"
+    "Add contacts or circles" : "Pridėti adresatus ar ratus",
+    "Signaling server URL" : "Signalinio serverio URL",
+    "Default location for attachments" : "Numatytoji priedų vieta",
+    "Select default location for attachments" : "Pasirinkti numatytąją vietą priedams"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
