@@ -39,8 +39,8 @@ OC.L10N.register(
     "You disallowed guests" : "Забранивте гости",
     "{actor} set a password" : "{actor} постави лозинка",
     "You set a password" : "Поставивте лозинка",
-    "{actor} removed the password" : "{actor} ја одстрани лозинката",
-    "You removed the password" : "Ја одстранивте лозинката",
+    "{actor} removed the password" : "{actor} ја отстрани лозинката",
+    "You removed the password" : "Ја отстранивте лозинката",
     "{actor} added {user}" : "{actor} го додаде {user}",
     "You joined the conversation" : "Се приклучивте кон разговорот",
     "{actor} joined the conversation" : "{actor} се приклучи кон разговорот",
@@ -48,9 +48,9 @@ OC.L10N.register(
     "{actor} added you" : "{actor} ве додаде",
     "You left the conversation" : "Го напуштивте разговорот",
     "{actor} left the conversation" : "{actor} го напушти разговорот",
-    "{actor} removed {user}" : "{actor} го одстрани {user}",
-    "You removed {user}" : "го одстранивте {user}",
-    "{actor} removed you" : "{actor} ве одстрани",
+    "{actor} removed {user}" : "{actor} го отстрани {user}",
+    "You removed {user}" : "го отстранивте {user}",
+    "{actor} removed you" : "{actor} ве отстрани",
     "{actor} promoted {user} to moderator" : "{actor} го промовираше {user} во модератор",
     "You promoted {user} to moderator" : "Го промовиравте {user} во модератор",
     "{actor} promoted you to moderator" : "{actor} ве промовираше во модератор",
@@ -187,6 +187,7 @@ OC.L10N.register(
     "Guinea-Bissau" : "Гвинеја-Бисао",
     "Guyana" : "Гвајана",
     "Hong Kong" : "Хонгконг",
+    "Heard Island and McDonald Islands" : "Островите Хард и Мекдоналдс",
     "Honduras" : "Хондурас",
     "Croatia" : "Хрватска",
     "Haiti" : "Хаити",
@@ -286,6 +287,7 @@ OC.L10N.register(
     "Singapore" : "Сингапур",
     "Saint Helena, Ascension and Tristan da Cunha" : "Света Елена, Вознесение и Тристан да Куња",
     "Slovenia" : "Словенија",
+    "Svalbard and Jan Mayen" : "Свалбард и Јан Мејн\n ",
     "Slovakia" : "Словачка",
     "Sierra Leone" : "Сиера Леоне",
     "San Marino" : "Сан Марино",
@@ -366,10 +368,10 @@ OC.L10N.register(
     "Language" : "Јазик",
     "Country" : "Држава",
     "Status" : "Статус",
+    "Created at" : "Создадено на",
     "Pending" : "Чекање",
     "Error" : "Грешка",
     "Active" : "Активно",
-    "Signaling server URL" : "URL за сервер за сигнализација",
     "Saved" : "Зачувано",
     "Copy link" : "Копирај линк",
     "Waiting for others to join the call …" : "Чекање на останатите да се приклучат кон повикот ...",
@@ -395,9 +397,10 @@ OC.L10N.register(
     "Enable video" : "Овозможи видео",
     "Screensharing options" : "Опции за споделување на екранот",
     "Enable screensharing" : "Овозможи споделување на екранот",
+    "Back" : "Назад",
     "Screen sharing is not supported by your browser." : "Споделување на екранот не е поддржано од вашиот пребарувач.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Споделување на екранот е поддржано со Firefox верзија 52 или понова.",
-    "You" : "Вие",
+    "You" : "Ти",
     "Show screen" : "Прикажи екран",
     "Mute" : "Занеми",
     "Call in progress" : "Повик е во тек",
@@ -407,7 +410,7 @@ OC.L10N.register(
     "Delete conversation" : "Избриши разговор",
     "Remove from favorites" : "Отстрани од фаворити",
     "Add to favorites" : "Додади во фаворити",
-    "You: {lastMessage}" : "Вие: {lastMessage}",
+    "You: {lastMessage}" : "Ти: {lastMessage}",
     "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
     "Do you really want to delete \"{displayName}\"?" : "Дали навистина сакате да го избришете \"{displayName}\"?",
     "You need to promote a new moderator before you can leave the conversation." : "Треба да промовирате нов модератор пред да го напуштите разговорот.",
@@ -416,18 +419,14 @@ OC.L10N.register(
     "No search results" : "Нема резултати од пребарувањето",
     "Groups" : "Групи",
     "Circles" : "Кругови",
-    "Default location for attachments" : "Стандардна локација за прилози",
+    "Settings" : "Параметри",
     "Groups and circles" : "Групи и кругови",
     "Other sources" : "Други извори",
-    "Select default location for attachments" : "Избери стандардна локација за прилози",
-    "Invalid path selected" : "Избрана невалидна патека",
-    "Error while setting attachment folder" : "Грешка при поставување на папка за прилози",
     "Copy conversation link" : "копирај линк од разговорот",
     "Link copied to the clipboard!" : "Линкот е копиран во клипборд!",
     "Create a new group conversation" : "Креирајте нов групен разговор",
     "Password protect" : "Заштити со лозинка",
     "Add participants" : "Додади учесници",
-    "Back" : "Назад",
     "Create conversation" : "Креирајте разговор",
     "Close" : "Затвори",
     "Choose a password" : "Избери лозинка",
@@ -436,7 +435,9 @@ OC.L10N.register(
     "Allow guests to join via link " : "Дозволи им на гостите да се приклучат преку линк",
     "You are currently waiting in the lobby" : "Моментално чекате во лобито",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Моментално чекате во лобито. Состанокот е закажан во {startTime}",
+    "Camera" : "Камера",
     "Reply" : "Одговор",
+    "Remove" : "Отстрани",
     "Today" : "Денес",
     "Yesterday" : "Вчера",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
@@ -444,10 +445,17 @@ OC.L10N.register(
     "Upload new files" : "Прикачи нови датотеки",
     "Share from Files" : "Сподели од датотеките",
     "File to share" : "Датотека за споделување",
+    "Invalid path selected" : "Избрана невалидна патека",
+    "Enabled" : "Овозможен",
+    "Save" : "Зачувај",
+    "Password" : "Лозинка",
+    "Login" : "Login",
+    "Nickname" : "Прекар",
+    "Client ID" : "Клиент ИД",
     "moderator" : "модератор",
     "guest" : "гостин",
     "Promote to moderator" : "Промовирај во модератор",
-    "Remove participant" : "Одстрани учесник",
+    "Remove participant" : "Отстрани учесник",
     "Add groups" : "Додади групи",
     "Add emails" : "Додади Е-пошти",
     "Add circles" : "Додади кругови",
@@ -459,10 +467,11 @@ OC.L10N.register(
     "Add participants to the conversation" : "Додадете учесници кон разговорот",
     "Participants" : "Учесници",
     "Chat" : "Разговор",
-    "Projects" : "Проекти",
-    "Settings" : "Параметри",
     "Display name: " : "Име:",
     "Edit" : "Уреди",
+    "Keyboard shortcuts" : "Кратенки преку тастатура",
+    "Search" : "Барај",
+    "Error while setting attachment folder" : "Грешка при поставување на папка за прилози",
     "Start call" : "Повик",
     "Go to file" : "Оди до датотеката",
     "Rename conversation" : "Преименувај разговор",
@@ -474,14 +483,15 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Излез од цел екран (f)",
     "Fullscreen (f)" : "Приказ на цел екран (f)",
     "Grid view" : "Мрежа",
+    "Say hi to your friends and colleagues!" : "Кажи им здраво на твојте пријатели и колеги!",
+    "Start a conversation" : "Започни разговор",
+    "Link to a conversation" : "Линк до разговорот",
     "Select conversation" : "Избери разговор",
     "Join a conversation or start a new one" : "Приклучи се кон разговор или започни нов",
-    "Say hi to your friends and colleagues!" : "Кажи им здраво на твојте пријатели и колеги!",
-    "Link to a conversation" : "Линк до разговорот",
     "Error while sharing file" : "Грешка при споделување на датотека",
     "Error while uploading file" : "Грешка при прикачување на датотека",
+    "Default" : "Стандардно",
     "The password is wrong. Try again." : "Лозинката е погрешна. Обидите се повторно.",
-    "Password" : "Лозинка",
     "TURN server" : "TURN сервер",
     "%s Talk on your mobile devices" : "%s Разговор на вашиоте мобилни уреди",
     "Join conversations at any time, anywhere, on any device." : "Придружете се на разговор во секое време, каде и да било, на кој било уред.",
@@ -490,6 +500,7 @@ OC.L10N.register(
     "Enter name for a new conversation" : "Внеси име за нов разговор",
     "{name} (public)" : "{name} (јавно)",
     "New conversation …" : "Нов разговор ...",
+    "Projects" : "Проекти",
     "Copy" : "Копирај",
     "Copied!" : "Копирано!",
     "Not supported!" : "Не е поддржано!",
@@ -547,6 +558,9 @@ OC.L10N.register(
     "Add contacts" : "Додади контакти",
     "Add contacts, groups or circles" : "Додади контакти, групи или кругови",
     "Add contacts or groups" : "Додади контакти или групи",
-    "Add contacts or circles" : "Додади контакти или кругови"
+    "Add contacts or circles" : "Додади контакти или кругови",
+    "Signaling server URL" : "URL за сервер за сигнализација",
+    "Default location for attachments" : "Стандардна локација за прилози",
+    "Select default location for attachments" : "Избери стандардна локација за прилози"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
