@@ -1,4 +1,5 @@
 <?php
+
 declare(strict_types=1);
 /**
  *
@@ -31,6 +32,8 @@ use OCP\App\IAppManager;
 use OCP\EventDispatcher\Event;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\EventDispatcher\IEventListener;
+use OCP\Files\IRootFolder;
+use OCP\ICacheFactory;
 use OCP\IConfig;
 use OCP\IInitialStateService;
 use OCP\IUser;
@@ -41,23 +44,28 @@ use OCP\Util;
  * Helper class to add the Talk UI to the sidebar of the Files app.
  */
 class TemplateLoader implements IEventListener {
-
 	use TInitialState;
 
 	/** @var IAppManager */
 	private $appManager;
+	/** @var IRootFolder */
+	private $rootFolder;
 	/** @var IUserSession */
 	private $userSession;
 
 	public function __construct(IInitialStateService $initialStateService,
+								ICacheFactory $memcacheFactory,
 								Config $talkConfig,
 								IConfig $serverConfig,
 								IAppManager $appManager,
+								IRootFolder $rootFolder,
 								IUserSession $userSession) {
 		$this->initialStateService = $initialStateService;
+		$this->memcacheFactory = $memcacheFactory;
 		$this->talkConfig = $talkConfig;
 		$this->serverConfig = $serverConfig;
 		$this->appManager = $appManager;
+		$this->rootFolder = $rootFolder;
 		$this->userSession = $userSession;
 	}
 
@@ -89,10 +97,9 @@ class TemplateLoader implements IEventListener {
 
 		$user = $this->userSession->getUser();
 		if ($user instanceof IUser) {
-			$this->publishInitialStateForUser($user, $this->appManager);
+			$this->publishInitialStateForUser($user, $this->rootFolder, $this->appManager);
 		} else {
 			$this->publishInitialStateForGuest();
 		}
 	}
-
 }
