@@ -244,6 +244,14 @@ class Notifier implements INotifier {
 		throw new \InvalidArgumentException('Unknown subject');
 	}
 
+	protected function shortenJsonEncodedMultibyteSave(string $subject, int $dataLength): string {
+		$temp = mb_substr($subject, 0, $dataLength);
+		while (strlen(json_encode($temp)) > $dataLength) {
+			$temp = mb_substr($temp, 0, -5);
+		}
+		return $temp;
+	}
+
 	/**
 	 * @param INotification $notification
 	 * @param Room $room
@@ -311,15 +319,42 @@ class Notifier implements INotifier {
 			}
 		}
 
-		$notification->setParsedMessage(str_replace($placeholders, $replacements, $message->getMessage()));
-		$notification->setRichMessage($message->getMessage(), $message->getMessageParameters());
+		$parsedMessage = str_replace($placeholders, $replacements, $message->getMessage());
+		if (!$this->notificationManager->isPreparingPushNotification()) {
+			$notification->setParsedMessage($parsedMessage);
+			$notification->setRichMessage($message->getMessage(), $message->getMessageParameters());
+		}
 
 		$richSubjectParameters = [
 			'user' => $richSubjectUser,
 			'call' => $richSubjectCall,
 		];
 
-		if ($notification->getSubject() === 'chat') {
+		if ($this->notificationManager->isPreparingPushNotification()) {
+			$shortenMessage = $this->shortenJsonEncodedMultibyteSave($parsedMessage, 100);
+			if ($shortenMessage !== $parsedMessage) {
+				$shortenMessage .= '…';
+			}
+			$richSubjectParameters['message'] = [
+				'type' => 'highlight',
+				'id' => $message->getComment()->getId(),
+				'name' => $shortenMessage,
+			];
+			if ($room->getType() === Room::ONE_TO_ONE_CALL) {
+				$subject = "{user}\n{message}";
+			} elseif ($richSubjectUser) {
+				$subject = $l->t('{user} in {call}') . "\n{message}";
+			} elseif (!$isGuest) {
+				$subject = $l->t('Deleted user in {call}') . "\n{message}";
+			} else {
+				try {
+					$richSubjectParameters['guest'] = $this->getGuestParameter($comment->getActorId());
+					$subject = $l->t('{guest} (guest) in {call}') . "\n{message}";
+				} catch (ParticipantNotFoundException $e) {
+					$subject = $l->t('Guest in {call}') . "\n{message}";
+				}
+			}
+		} elseif ($notification->getSubject() === 'chat') {
 			if ($room->getType() === Room::ONE_TO_ONE_CALL) {
 				$subject = $l->t('{user} sent you a private message');
 			} elseif ($richSubjectUser) {
